@@ -152,7 +152,7 @@ impl Args {
         // Iterate over the inputs with “while let” because we need to advance
         // the iterator manually whenever an argument that takes a value
         // doesn’t have one in its string so it needs the next one.
-        let mut inputs = inputs.into_iter();
+        let mut inputs = inputs.into_iter().peekable();
         while let Some(arg) = inputs.next() {
             let bytes = os_str_to_bytes(arg);
 
@@ -198,13 +198,12 @@ impl Args {
                                 return Err(ParseError::NeedsValue { flag, values });
                             }
                         }
-                        TakesValue::Optional(_) => {
-                            if let Some(next_arg) = inputs.next() {
-                                result_flags.push((flag, Some(next_arg)));
-                            } else {
-                                result_flags.push((flag, None));
+                        TakesValue::Optional(_) => match inputs.peek() {
+                            Some(next_arg) if is_optional_arg(next_arg) => {
+                                result_flags.push((flag, Some(inputs.next().unwrap())));
                             }
-                        }
+                            _ => result_flags.push((flag, None)),
+                        },
                     }
                 }
             }
@@ -332,6 +331,15 @@ impl Args {
     }
 }
 
+fn is_optional_arg(arg: &OsStr) -> bool {
+    let bytes = os_str_to_bytes(arg);
+    match bytes {
+        // The only optional arguments allowed
+        b"always" | b"auto" | b"automatic" | b"never" => true,
+        _ => false,
+    }
+}
+
 /// The **matches** are the result of parsing the user’s command-line strings.
 #[derive(PartialEq, Eq, Debug)]
 pub struct Matches<'args> {
